.. _interface:

===========================
Timeserie Interface
===========================


Dynts data class
=============================

.. autoclass:: dynts.DynData
   :members:
   :member-order: bysource  
   
   
Interface class
======================

.. autoclass:: dynts.TimeSeries
   :members:
   :member-order: bysource 
   

XY data class
=============================

.. autoclass:: dynts.xydata
   :members:
   :member-order: bysource     